@@ -12,20 +12,18 @@ use overload
 	fallback	=> 1;
 
 # https://developer.mozilla.org/pl/docs/Web/API/Element/nodeType
-use constant {
-	ELEMENT_NODE					=> 1, 
-	ATTRIBUTE_NODE					=> 2,	# not supported
-	TEXT_NODE						=> 3, 
-	CDATA_SECTION_NODE				=> 4,	# not supported
-	ENTITY_REFERENCE_NODE			=> 5,	# not supported
-	ENTITY_NODE						=> 6,	# not supported
-	PROCESSING_INSTRUCTION_NODE		=> 7,	# not supported
-	COMMENT_NODE					=> 8, 
-	DOCUMENT_NODE					=> 9, 
-	DOCUMENT_TYPE_NODE				=> 10, 
-	DOCUMENT_FRAGMENT_NODE			=> 11, 
-	NOTATION_NODE					=> 12	# not supported
-};
+use constant	ELEMENT_NODE					=> 1; 
+use constant	ATTRIBUTE_NODE					=> 2;	# not supported
+use constant	TEXT_NODE						=> 3; 
+use constant	CDATA_SECTION_NODE				=> 4;	# not supported
+use constant	ENTITY_REFERENCE_NODE			=> 5;	# not supported
+use constant	ENTITY_NODE						=> 6;	# not supported
+use constant	PROCESSING_INSTRUCTION_NODE		=> 7;	# not supported
+use constant	COMMENT_NODE					=> 8; 
+use constant	DOCUMENT_NODE					=> 9; 
+use constant	DOCUMENT_TYPE_NODE				=> 10; 
+use constant	DOCUMENT_FRAGMENT_NODE			=> 11; 
+use constant	NOTATION_NODE					=> 12;	# not supported
 
 sub __attrHashAccess {
 	my $self = shift;
